Board
=====

GraphType
---------

.. autoclass:: sokoenginepy.game.GraphType
    :members:
    :undoc-members:

BoardCell
---------

.. autoclass:: sokoenginepy.game.BoardCell
    :members:
    :undoc-members:

BoardGraph
----------

.. autoclass:: sokoenginepy.game.BoardGraph
    :members:
    :undoc-members:
    :inherited-members:
    :member-order: bysource
    :special-members: __init__, __getitem__, __setitem__, __contains__
